Thanks for your interest in contributing. If you want to fix a bug or add a feature, please check out our dev setup documentation [page](https://agentdojo.spylab.ai/development/).

If you want to add a new attack or defense, please open a PR or an issue. We will soon add an issue template to make this easier and standardized.
